==> openflowplugin-extension-nicira-0.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/value/_case/FlowModAddMatchFromValue.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint16;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-add-match-from-value {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf value {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-value-case/flow-mod-add-match-from-value</i>
 *
 * <p>To create instances of this class use {@link FlowModAddMatchFromValueBuilder}.
 * @see FlowModAddMatchFromValueBuilder
 *
 */
public interface FlowModAddMatchFromValue
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModAddMatchFromValue>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-add-match-from-value");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getFlowModNumBits();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>value</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getValue();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>srcField</code>, or <code>null</code> if not present
     */
    @Nullable Uint32 getSrcField();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    @Nullable Uint16 getSrcOfs();

}

==> openflowplugin-extension-nicira-0.11.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/flow/mod/spec/flow/mod/spec/flow/mod/add/match/from/value/_case/FlowModAddMatchFromValue.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.FlowModSpec;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;
import org.opendaylight.yangtools.yang.common.Uint16;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * container flow-mod-add-match-from-value {
 *   leaf flow-mod-num-bits {
 *     type uint16;
 *   }
 *   leaf value {
 *     type uint16;
 *   }
 *   leaf src-field {
 *     type uint32;
 *   }
 *   leaf src-ofs {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/flow-mod-spec/flow-mod-spec/flow-mod-add-match-from-value-case/flow-mod-add-match-from-value</i>
 *
 * <p>To create instances of this class use {@link FlowModAddMatchFromValueBuilder}.
 * @see FlowModAddMatchFromValueBuilder
 *
 */
public interface FlowModAddMatchFromValue
    extends
    ChildOf<FlowModSpec>,
    Augmentable<FlowModAddMatchFromValue>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("flow-mod-add-match-from-value");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.flow.mod.spec.flow.mod.spec.flow.mod.add.match.from.value._case.FlowModAddMatchFromValue.class;
    }
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>flowModNumBits</code>, or <code>null</code> if not present
     */
    Uint16 getFlowModNumBits();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>value</code>, or <code>null</code> if not present
     */
    Uint16 getValue();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint32</code> <code>srcField</code>, or <code>null</code> if not present
     */
    Uint32 getSrcField();
    
    /**
     * @return <code>org.opendaylight.yangtools.yang.common.Uint16</code> <code>srcOfs</code>, or <code>null</code> if not present
     */
    Uint16 getSrcOfs();

}
